==> ark_24.12.2.orig.tar.xz: ark-24.12.2/part/ark_part.json.cmake <==
{
    "KPlugin": {
        "Description": "Archive Handling Tool",
        "Description[ar]": "أداة التعامل مع الملفات المضغوطة",
        "Description[ast]": "Ferramienta pa remanar archivos",
        "Description[az]": "Arxivləşdirmə aləti",
        "Description[be]": "Інструмент для апрацоўвання архіваў",
        "Description[bg]": "Инструмент за обработка на архиви",
        "Description[ca@valencia]": "Eina de gestió d'arxius",
        "Description[ca]": "Eina de gestió d'arxius",
        "Description[cs]": "Program pro práci s archivy",
        "Description[da]": "Arkivbehandlingsværktøj",
        "Description[de]": "Archiv-Verwaltung",
        "Description[el]": "Εργαλείο χειρισμού αρχειοθηκών",
        "Description[en_GB]": "Archive Handling Tool",
        "Description[eo]": "Arkivpritrakta Ilo",
        "Description[es]": "Herramienta de gestión de archivos comprimidos",
        "Description[eu]": "Artxiboak kudeatzeko tresna",
        "Description[fi]": "Arkistonkäsittelyohjelma",
        "Description[fr]": "Outil de manipulation d'archives",
        "Description[gl]": "Utilidade de manexo de arquivos.",
        "Description[he]": "כלי לניהול ארכיונים",
        "Description[hu]": "Archívumkezelő program",
        "Description[ia]": "Instrumento de manear archivo",
        "Description[ie]": "Utensile por labor con archives",
        "Description[is]": "Verkfæri fyrir safnskrár",
        "Description[it]": "Strumento di gestione degli archivi",
        "Description[ja]": "アーカイブ処理ツール",
        "Description[ka]": "არქივებთან სამუშაო ხელსაწყო",
        "Description[ko]": "압축 파일 처리 도구",
        "Description[lt]": "Archyvų apdorojimo įrankis",
        "Description[lv]": "Arhīvu apstrādes rīks",
        "Description[nl]": "Hulpprogramma voor het beheren van archieven",
        "Description[nn]": "Verktøy for arkivhandsaming",
        "Description[pa]": "ਅਕਾਇਵ ਹੈਡਲਿੰਗ ਟੂਲ",
        "Description[pl]": "Program obsługi archiwów",
        "Description[pt]": "Ferramenta de Tratamento de Pacotes",
        "Description[pt_BR]": "Ferramenta de manipulação de arquivos",
        "Description[ro]": "Utilitar de manipulare a arhivelor",
        "Description[ru]": "Программа для работы с архивами",
        "Description[sk]": "Nástroj na prácu s archívmi",
        "Description[sl]": "Orodje za upravljanje arhivov",
        "Description[sv]": "Arkivhanteringsverktyg",
        "Description[tr]": "Arşiv İşleme Aracı",
        "Description[uk]": "Інструмент для роботи з архівами",
        "Description[x-test]": "xxArchive Handling Toolxx",
        "Description[zh_CN]": "压缩文件管理工具",
        "Description[zh_TW]": "封存檔處理工具",
        "Icon": "ark",
        "License": "GPL v2+",
        "MimeTypes": [
            "@SUPPORTED_ARK_MIMETYPES_JSON@"
        ],
        "Name": "Archiver",
        "Name[ar]": "المؤرشف",
        "Name[ast]": "Archivador",
        "Name[az]": "Arxivləyici",
        "Name[be]": "Архіватар",
        "Name[bg]": "Архиватор",
        "Name[ca@valencia]": "Arxivador",
        "Name[ca]": "Arxivador",
        "Name[cs]": "Archivátor",
        "Name[da]": "Arkivbehandler",
        "Name[de]": "Archivierer",
        "Name[el]": "Αρχειοθέτης",
        "Name[en_GB]": "Archiver",
        "Name[eo]": "Arkivilo",
        "Name[es]": "Archivador",
        "Name[eu]": "Artxibatzailea",
        "Name[fi]": "Arkistointi",
        "Name[fr]": "Archiveur",
        "Name[gl]": "Arquivador",
        "Name[he]": "מנהל ארכיונים",
        "Name[hu]": "Fájltömörítő",
        "Name[ia]": "Archivaor",
        "Name[ie]": "Archivator",
        "Name[is]": "Skráasafnari",
        "Name[it]": "Utilità di archiviazione",
        "Name[ja]": "アーカイバ",
        "Name[ka]": "არქივატორი",
        "Name[ko]": "압축 도구",
        "Name[lt]": "Archyvavimo programa",
        "Name[lv]": "Arhivēšanas rīks",
        "Name[nl]": "Archiefgereedschap",
        "Name[nn]": "Arkivprogram",
        "Name[pa]": "ਅਕਾਇਵਰ",
        "Name[pl]": "Archiwizer",
        "Name[pt]": "Ark",
        "Name[pt_BR]": "Arquivador",
        "Name[ro]": "Arhivator",
        "Name[ru]": "Архиватор",
        "Name[sk]": "Archivačný nástroj",
        "Name[sl]": "Arhivar",
        "Name[sv]": "Arkiverare",
        "Name[ta]": "காப்பக உருவாக்கி",
        "Name[tr]": "Arşivleyici",
        "Name[uk]": "Архіватор",
        "Name[x-test]": "xxArchiverxx",
        "Name[zh_CN]": "压缩文件管理工具",
        "Name[zh_TW]": "封存工具",
        "ServiceTypes": [
            "KParts/ReadOnlyPart",
            "Browser/View"
        ],
        "Version": "@ARK_VERSION@",
        "Website": "https://utils.kde.org/projects/ark"
    }
}

==> ark_25.04.3.orig.tar.xz: ark-25.04.3/part/ark_part.json.cmake <==
{
    "KPlugin": {
        "Description": "Archive Handling Tool",
        "Description[ar]": "أداة التعامل مع الملفات المضغوطة",
        "Description[ast]": "Ferramienta pa remanar archivos",
        "Description[az]": "Arxivləşdirmə aləti",
        "Description[be]": "Інструмент для апрацоўвання архіваў",
        "Description[bg]": "Инструмент за обработка на архиви",
        "Description[ca@valencia]": "Eina de gestió d'arxius",
        "Description[ca]": "Eina de gestió d'arxius",
        "Description[cs]": "Program pro práci s archivy",
        "Description[da]": "Arkivbehandlingsværktøj",
        "Description[de]": "Archiv-Verwaltung",
        "Description[el]": "Εργαλείο χειρισμού αρχειοθηκών",
        "Description[en_GB]": "Archive Handling Tool",
        "Description[eo]": "Arkivpritrakta Ilo",
        "Description[es]": "Herramienta de gestión de archivos comprimidos",
        "Description[eu]": "Artxiboak kudeatzeko tresna",
        "Description[fi]": "Arkistonkäsittelyohjelma",
        "Description[fr]": "Outil de manipulation d'archives",
        "Description[gl]": "Utilidade de manexo de arquivos.",
        "Description[he]": "כלי לניהול ארכיונים",
        "Description[hu]": "Archívumkezelő program",
        "Description[ia]": "Instrumento de manear archivo",
        "Description[ie]": "Utensile por labor con archives",
        "Description[is]": "Verkfæri fyrir safnskrár",
        "Description[it]": "Strumento di gestione degli archivi",
        "Description[ja]": "アーカイブ処理ツール",
        "Description[ka]": "არქივებთან სამუშაო ხელსაწყო",
        "Description[ko]": "압축 파일 처리 도구",
        "Description[lt]": "Archyvų apdorojimo įrankis",
        "Description[lv]": "Arhīvu apstrādes rīks",
        "Description[nl]": "Hulpprogramma voor het beheren van archieven",
        "Description[nn]": "Verktøy for arkivhandsaming",
        "Description[pa]": "ਅਕਾਇਵ ਹੈਡਲਿੰਗ ਟੂਲ",
        "Description[pl]": "Program obsługi archiwów",
        "Description[pt]": "Ferramenta de Tratamento de Pacotes",
        "Description[pt_BR]": "Ferramenta de manipulação de arquivos",
        "Description[ro]": "Utilitar de manipulare a arhivelor",
        "Description[ru]": "Программа для работы с архивами",
        "Description[sa]": "आर्काइव हैंडलिंग टूल",
        "Description[sk]": "Nástroj na prácu s archívmi",
        "Description[sl]": "Orodje za upravljanje arhivov",
        "Description[sv]": "Arkivhanteringsverktyg",
        "Description[tr]": "Arşiv İşleme Aracı",
        "Description[uk]": "Інструмент для роботи з архівами",
        "Description[x-test]": "xxArchive Handling Toolxx",
        "Description[zh_CN]": "压缩文件管理工具",
        "Description[zh_TW]": "封存檔處理工具",
        "Icon": "ark",
        "License": "GPL v2+",
        "MimeTypes": [
            "@SUPPORTED_ARK_MIMETYPES_JSON@"
        ],
        "Name": "Archiver",
        "Name[ar]": "المؤرشف",
        "Name[ast]": "Archivador",
        "Name[az]": "Arxivləyici",
        "Name[be]": "Архіватар",
        "Name[bg]": "Архиватор",
        "Name[ca@valencia]": "Arxivador",
        "Name[ca]": "Arxivador",
        "Name[cs]": "Archivátor",
        "Name[da]": "Arkivbehandler",
        "Name[de]": "Archivierer",
        "Name[el]": "Αρχειοθέτης",
        "Name[en_GB]": "Archiver",
        "Name[eo]": "Arkivilo",
        "Name[es]": "Archivador",
        "Name[eu]": "Artxibatzailea",
        "Name[fi]": "Arkistointi",
        "Name[fr]": "Archiveur",
        "Name[gl]": "Arquivador",
        "Name[he]": "מנהל ארכיונים",
        "Name[hu]": "Fájltömörítő",
        "Name[ia]": "Archivator",
        "Name[ie]": "Archivator",
        "Name[is]": "Skráasafnari",
        "Name[it]": "Utilità di archiviazione",
        "Name[ja]": "アーカイバ",
        "Name[ka]": "არქივატორი",
        "Name[ko]": "압축 도구",
        "Name[lt]": "Archyvavimo programa",
        "Name[lv]": "Arhivēšanas rīks",
        "Name[nl]": "Archiefgereedschap",
        "Name[nn]": "Arkivprogram",
        "Name[pa]": "ਅਕਾਇਵਰ",
        "Name[pl]": "Archiwizer",
        "Name[pt]": "Ark",
        "Name[pt_BR]": "Arquivador",
        "Name[ro]": "Arhivator",
        "Name[ru]": "Архиватор",
        "Name[sa]": "लेखागार",
        "Name[sk]": "Archivačný nástroj",
        "Name[sl]": "Arhivar",
        "Name[sv]": "Arkiverare",
        "Name[ta]": "காப்பக உருவாக்கி",
        "Name[tr]": "Arşivleyici",
        "Name[uk]": "Архіватор",
        "Name[x-test]": "xxArchiverxx",
        "Name[zh_CN]": "压缩文件管理工具",
        "Name[zh_TW]": "封存工具",
        "ServiceTypes": [
            "KParts/ReadOnlyPart",
            "Browser/View"
        ],
        "Version": "@ARK_VERSION@",
        "Website": "https://utils.kde.org/projects/ark"
    }
}
